@@ -8,10 +8,7 @@ import glob
 import logging
 import os.path
 
-# This is what we want for the future (Python 2.9 an beyond):
-# import importlib.resources as importlib_resources
-# but right now we have to support Py 3.8, so we have this:
-import pkg_resources
+import importlib.resources as importlib_resources
 
 # Third party imports
 import numpy as np
@@ -113,7 +110,9 @@ class BooreKishida2017(ComponentConverter):
                 ]
             ),
             IMC.GMRotI50: set([IMC.RotD50, IMC.GREATER_OF_TWO_HORIZONTAL]),
-            IMC.GEOMETRIC_MEAN: set([IMC.RotD50, IMC.GREATER_OF_TWO_HORIZONTAL]),
+            IMC.GEOMETRIC_MEAN: set(
+                [IMC.RotD50, IMC.GREATER_OF_TWO_HORIZONTAL]
+            ),
             IMC.RotD100: set([IMC.RotD50, IMC.GREATER_OF_TWO_HORIZONTAL]),
             IMC.GREATER_OF_TWO_HORIZONTAL: set(
                 [
@@ -127,8 +126,12 @@ class BooreKishida2017(ComponentConverter):
                 ]
             ),
             IMC.HORIZONTAL: set([IMC.GREATER_OF_TWO_HORIZONTAL, IMC.RotD50]),
-            IMC.MEDIAN_HORIZONTAL: set([IMC.GREATER_OF_TWO_HORIZONTAL, IMC.RotD50]),
-            IMC.RANDOM_HORIZONTAL: set([IMC.GREATER_OF_TWO_HORIZONTAL, IMC.RotD50]),
+            IMC.MEDIAN_HORIZONTAL: set(
+                [IMC.GREATER_OF_TWO_HORIZONTAL, IMC.RotD50]
+            ),
+            IMC.RANDOM_HORIZONTAL: set(
+                [IMC.GREATER_OF_TWO_HORIZONTAL, IMC.RotD50]
+            ),
         }
         # Check if any imc values are unknown. If they are, convert
         # to GEOMETRIC_MEAN
@@ -224,7 +227,7 @@ class BooreKishida2017(ComponentConverter):
         # Get coeffecients
         (sigma, c0, r1, m1, m2) = self._getParamsFromIMT(imt)
         # Calculate conversion
-        sigmas = np.sqrt(sigmas ** 2 + sigma ** 2)
+        sigmas = np.sqrt(sigmas**2 + sigma**2)
 
         return sigmas
 
@@ -278,11 +281,8 @@ class BooreKishida2017(ComponentConverter):
             string 'Null', then imc_in and imc_out evaluated to be the
             same.
         """
-        # This is what we want for the future (Python 2.9 an beyond):
-        # datadir = importlib_resources.files("esi_shakelib.conversions.imc") / "data"
-        # but right now we have to support Py 3.8, so we have this:
-        datadir = pkg_resources.resource_filename(
-            "esi_shakelib.conversions.imc", "data"
+        datadir = (
+            importlib_resources.files("esi_shakelib.conversions.imc") / "data"
         )
         conv_files = glob.glob(os.path.join(datadir, "*.csv"))
         stub1 = BooreKishida2017._imcToFilestr(imc_in)
@@ -353,7 +353,9 @@ class BooreKishida2017(ComponentConverter):
         """
         filename, forward = self._imcPairToFile(imc_in, imc_out)
         if filename is None:
-            raise ValueError(f"Can't find a conversion file for {imc_in} and {imc_out}")
+            raise ValueError(
+                f"Can't find a conversion file for {imc_in} and {imc_out}"
+            )
         self.forward = forward
         if filename == "Null":
             # Null conversion -- imc_in and imc_out are either identical
