@@ -7,7 +7,6 @@ import copy
 from enum import Enum
 
 import numpy as np
-from scipy import integrate
 from scipy.stats import norm
 from scipy.stats import truncnorm
 import openquake.hazardlib.const as oqconst
@@ -16,11 +15,6 @@ from esi_utils_rupture.quad_rupture import QuadRupture
 from esi_utils_rupture.point_rupture import PointRupture
 from esi_utils_rupture.distance import Distance
 from esi_shakelib.sites import Sites
-from esi_shakelib.utils.contexts import (
-    SitesContext,
-    DistancesContext,
-    RuptureContext,
-)
 
 
 class AutoName(Enum):
@@ -663,8 +657,8 @@ class RandomFiniteFault(object):
         max_strike=180.0,
         min_dip=None,
         max_dip=None,
-        dx_min_frac=0.0,
-        dx_max_frac=1.0,
+        dy_min_frac=0.0,
+        dy_max_frac=1.0,
         ztor=-1,
         aspect_ratio=-1,
         min_sz_depth=0,
@@ -686,9 +680,9 @@ class RandomFiniteFault(object):
                 degrees) of the realized faults. The default is to use the
                 "mech" of the origin to limit the range or, if none, use
                 the "ALL" mech which defaults to 35/90.
-            dx_min_frac/dx_max_frac (float/float): Limit the range of the
+            dy_min_frac/dy_max_frac (float/float): Limit the range of the
                 along-strike placement of the hypocenter to from
-                dx_min_frac * length to dx_max_frac * length. (default
+                dy_min_frac * length to dy_max_frac * length. (default
                 0.0/1.0)
             ztor (float): Fix the top of rupture to a specific depth
                 (kilometers, positive down). Negative values allow the
@@ -716,8 +710,8 @@ class RandomFiniteFault(object):
             max_strike,
             min_dip,
             max_dip,
-            dx_min_frac,
-            dx_max_frac,
+            dy_min_frac,
+            dy_max_frac,
             ztor,
             aspect_ratio,
             min_sz_depth,
@@ -731,8 +725,8 @@ class RandomFiniteFault(object):
         max_strike,
         min_dip,
         max_dip,
-        dx_min_frac,
-        dx_max_frac,
+        dy_min_frac,
+        dy_max_frac,
         ztor,
         aspect_ratio,
         min_sz_depth,
@@ -779,7 +773,7 @@ class RandomFiniteFault(object):
         else:
             aspect = aspect_ratio
         width = np.sqrt(area / aspect)
-        # Need to apply a max to dy that might be less than width based on the
+        # Need to apply a max to dx that might be less than width based on the
         # eq depth.
         # height = vertical projection of plane
         # height = width * sin(dip)
@@ -788,7 +782,7 @@ class RandomFiniteFault(object):
         #  \dip    |       |
         #   \      |       |
         #    \     |       |
-        #   dy\    |height |
+        #   dx\    |height |
         #      *- -|- - - - depth
         #       \  |
         #        \ |
@@ -803,20 +797,22 @@ class RandomFiniteFault(object):
         # Limit the rupture to stay between 0 and the max_sz_depth
         # but allow it to float in between
         if ztor < 0:
-            dy_min = np.maximum(0, width - (szdepth - depth) / np.sin(dip))
-            dy_max = np.minimum(width, width - (height - depth) / np.sin(dip))
-            dy = dy_min + self.rnd_weibull(self.nsim) * (dy_max - dy_min)
+            dx_min = np.maximum(0, width - (szdepth - depth) / np.sin(dip))
+            dx_max = np.minimum(width, width - (height - depth) / np.sin(dip))
+            dx = dx_min + self.rnd_weibull(
+                dx_min, dx_max, width, self.nsim
+            ) * (dx_max - dx_min)
         else:
             # Fix ztor to a specific depth. This is a weak contraint: there is
             # no guarantee that for a given depth, dip, and width that the TOR
             # will reach ztor
-            dy = (depth - ztor) / np.sin(dip)
-            dy[dy > width] = width[dy > width]
+            dx = (depth - ztor) / np.sin(dip)
+            dx[dx > width] = width[dx > width]
 
         length = area / width
-        dx_min = dx_min_frac * length
-        dx_max = dx_max_frac * length
-        if dx_min_frac == 0 and dx_max_frac == 1:
+        dy_min = dy_min_frac * length
+        dy_max = dy_max_frac * length
+        if dy_min_frac == 0 and dy_max_frac == 1:
             a_trunc = 0.0
             b_trunc = 1.0
             loc = 0.5
@@ -832,7 +828,7 @@ class RandomFiniteFault(object):
             )
         else:
             frac = self.rng.uniform(size=self.nsim)
-        dx = dx_min + frac * (dx_max - dx_min)
+        dy = dy_min + frac * (dy_max - dy_min)
         strike = self.rng.uniform(min_strike, max_strike, self.nsim)
         hx = np.array([hypo.x])
         hy = np.array([hypo.y])
@@ -843,8 +839,8 @@ class RandomFiniteFault(object):
                     hx,
                     hy,
                     np.array([depth[idx]]),
-                    [dx[idx]],
                     [dy[idx]],
+                    [dx[idx]],
                     [length[idx]],
                     [width[idx]],
                     [strike[idx]],
@@ -870,21 +866,19 @@ class RandomFiniteFault(object):
         """
         return self.nsim
 
-    def rnd_weibull(self, nsamp):
+    def rnd_weibull(self, dx_min, dx_max, width, nsamp):
         """
-        Compute random samples from the Weibull distribution using
-        inverse transform sampling.
+        Compute random samples from the Weibull distribution.
+        Truncate the distribution at 1.
         """
         A = 0.612
         B = 3.353
-        x = np.linspace(0, 1, 1000)
-        y = weibull(A, B, x)
-        cdf = integrate.cumulative_trapezoid(y, x, initial=x[0])
-        nrm = cdf[-1] - cdf[0]
-        cdf = cdf / nrm
-        icdf = np.interp(x, cdf, x)
-        uniform_samples = self.rng.uniform(size=nsamp)
-        rnd_array = np.interp(uniform_samples, x, icdf)
+        frac_min = dx_min / width
+        frac_max = dx_max / width
+        x_min = np.exp(-np.power(frac_max / A, B))
+        x_max = np.exp(-np.power(frac_min / A, B))
+        unif = self.rng.uniform(x_min, x_max, size=nsamp)
+        rnd_array = A * np.power(-np.log(unif), 1 / B)
         return rnd_array
 
 
@@ -906,13 +900,6 @@ def calc_asp(M, nu):
     return aspect
 
 
-def weibull(A, B, x):
-    """
-    The Weibull distribution.
-    """
-    return (B / A) * np.power(x / A, B - 1) * np.exp(-np.power(x / A, B))
-
-
 def get_scaling_params(origin):
     """
 
