@@ -1,7 +1,7 @@
 """
 Module to implement supported regional models from Kuehn et al. (2020).
 This entire module can be removed (and its import into multigmpe.py) as
-soon as the next version of openquake-engine hits pypi (v3.20.1 is the 
+soon as the next version of openquake-engine hits pypi (v3.20.1 is the
 current version).
 """
 
@@ -22,5 +22,7 @@ for region in SUPPORTED_REGIONS[1:]:
 
 for region in SUPPORTED_REGIONS[1:]:
     add_alias(
-        "KuehnEtAl2020SSlab" + REGION_ALIASES[region], KuehnEtAl2020SSlab, region=region
+        "KuehnEtAl2020SSlab" + REGION_ALIASES[region],
+        KuehnEtAl2020SSlab,
+        region=region,
     )
