@@ -10,7 +10,9 @@ import numpy as np
 from openquake.hazardlib import const
 from openquake.hazardlib.gsim.base import GMPE
 from openquake.hazardlib.gsim.boore_2014 import BooreEtAl2014
-from openquake.hazardlib.gsim.campbell_bozorgnia_2014 import CampbellBozorgnia2014
+from openquake.hazardlib.gsim.campbell_bozorgnia_2014 import (
+    CampbellBozorgnia2014,
+)
 from openquake.hazardlib.imt import PGA, PGV, SA
 from openquake.hazardlib.valid import gsim
 
@@ -18,7 +20,9 @@ from openquake.hazardlib.valid import gsim
 from esi_shakelib.utils.contexts import RuptureContext
 from esi_shakelib.utils.gmpe_coeffs import get_gmpe_sa_periods
 from esi_shakelib.conversions.imc.boore_kishida_2017 import BooreKishida2017
-from esi_shakelib.conversions.imt.abrahamson_bhasin_2020 import AbrahamsonBhasin2020
+from esi_shakelib.conversions.imt.abrahamson_bhasin_2020 import (
+    AbrahamsonBhasin2020,
+)
 from esi_shakelib.multiutils import gmpe_gmas
 from esi_shakelib.sites import addDepthParameters
 
@@ -220,7 +224,9 @@ class MultiGMPE(GMPE):
         if not isinstance(imt, list):
             imt = [imt]
         # Evaluate MultiGMPE:
-        lnmu, lnsd = self.__get_mean_and_stddevs__(sites, rup, dists, imt, stddev_types)
+        lnmu, lnsd = self.__get_mean_and_stddevs__(
+            sites, rup, dists, imt, stddev_types
+        )
 
         return lnmu, lnsd
 
@@ -256,7 +262,8 @@ class MultiGMPE(GMPE):
             # -----------------------------------------------------------------
 
             gmpe_imts = [
-                imt.__name__ for imt in list(gmpe.DEFINED_FOR_INTENSITY_MEASURE_TYPES)
+                imt.__name__
+                for imt in list(gmpe.DEFINED_FOR_INTENSITY_MEASURE_TYPES)
             ]
 
             timt = copy.copy(imt)
@@ -339,10 +346,11 @@ class MultiGMPE(GMPE):
                             kimt, lmean[kk], dists.rrup, rup.mag
                         )
                         #
-                        # The extra sigma from the component conversion appears to
-                        # apply to the total sigma, so the question arises as to
-                        # how to apportion it between the intra- and inter-event
-                        # sigma. Here we assume it all enters as intra-event sigma.
+                        # The extra sigma from the component conversion
+                        # appears to apply to the total sigma, so the
+                        # question arises as to how to apportion it between
+                        # the intra- and inter-event sigma. Here we assume
+                        # it all enters as intra-event sigma.
                         #
                         for j, stddev_type in enumerate(stddev_types):
                             if stddev_type == const.StdDev.INTER_EVENT:
@@ -400,7 +408,9 @@ class MultiGMPE(GMPE):
             for i in range(nsd):
                 sdlist = []
                 for j in range(nwts):
-                    sdlist.append(lnsd_list[kk][j * nsd + i].reshape((1, 1, -1)))
+                    sdlist.append(
+                        lnsd_list[kk][j * nsd + i].reshape((1, 1, -1))
+                    )
                 sdstack = np.hstack(sdlist)
                 wcov = (sdstack * np.transpose(sdstack, axes=(1, 0, 2))) * cc
                 # This sums the weighted covariance as each point in the output
@@ -446,8 +456,12 @@ class MultiGMPE(GMPE):
             # If it is a GMPE set, does it contain GMPEs or GMPE sets?
             # -----------------------------------------------------------------
 
-            set_of_gmpes = all([s in conf["gmpe_modules"] for s in selected_gmpe_sets])
-            set_of_sets = all([s in conf["gmpe_sets"] for s in selected_gmpe_sets])
+            set_of_gmpes = all(
+                s in conf["gmpe_modules"] for s in selected_gmpe_sets
+            )
+            set_of_sets = all(
+                s in conf["gmpe_sets"] for s in selected_gmpe_sets
+            )
 
             if set_of_sets is True:
                 mgmpes = []
@@ -482,7 +496,10 @@ class MultiGMPE(GMPE):
             # tmpclass = getattr(mod, modinfo[0])
             # out = MultiGMPE.__from_list__([tmpclass()], [1.0], imc=imc)
             out = MultiGMPE.__from_list__(
-                [get_gmpe_from_name(modinfo[0], conf)], [1.0], imc=imc, imt=filter_imt
+                [get_gmpe_from_name(modinfo[0], conf)],
+                [1.0],
+                imc=imc,
+                imt=filter_imt,
             )
             if out is None:
                 return None
@@ -624,7 +641,9 @@ class MultiGMPE(GMPE):
         # ---------------------------------------------------------------------
 
         if len(weights) != len(gmpes):
-            raise ValueError("Length of weights must match length of GMPE list.")
+            raise ValueError(
+                "Length of weights must match length of GMPE list."
+            )
 
         # ---------------------------------------------------------------------
         # Check that gmpes is a list of OQ GMPE instances
@@ -761,12 +780,18 @@ def filter_gmpe_list(gmpes, wts, imt):
         sgmpe = [
             g
             for g in gmpes
-            if any("PGA" in t.__name__ for t in g.DEFINED_FOR_INTENSITY_MEASURE_TYPES)
+            if any(
+                "PGA" in t.__name__
+                for t in g.DEFINED_FOR_INTENSITY_MEASURE_TYPES
+            )
         ]
         swts = [
             w
             for g, w in zip(gmpes, wts)
-            if any("PGA" in t.__name__ for t in g.DEFINED_FOR_INTENSITY_MEASURE_TYPES)
+            if any(
+                "PGA" in t.__name__
+                for t in g.DEFINED_FOR_INTENSITY_MEASURE_TYPES
+            )
         ]
     elif imt == PGV():
         sgmpe = []
