@@ -4,15 +4,20 @@ import importlib.metadata
 
 # third party imports
 import numpy as np
+from strec.gmreg import Regionalizer
+
 from esi_utils_rupture.base import Rupture
 from esi_utils_rupture.edge_rupture import EdgeRupture
 from esi_utils_rupture.quad_rupture import QuadRupture
 from openquake.hazardlib import const, imt
 from openquake.hazardlib.geo.utils import OrthographicProjection
-from esi_shakelib.utils.contexts import SitesContext, DistancesContext, RuptureContext
+from esi_shakelib.utils.contexts import (
+    SitesContext,
+    DistancesContext,
+    RuptureContext,
+)
 from esi_shakelib.multigmpe import set_sites_depth_parameters
 from esi_shakelib.station import StationList
-from strec.gmreg import Regionalizer
 
 DEFAULT_ACTIVE_COEFFS = [27.24, 250.4, 579.1]
 DEFAULT_STABLE_COEFFS = [63.4, 465.4, 581.3]
@@ -27,7 +32,8 @@ def replace_dyfi(stationfile, dyfi_xml, min_nresp=3):
         dyfi_xml (str): DYFI XML data file, which will be added to
                         instrumented station data.
         min_nresp (int): The minimum number of DYFI responses required for an
-                         observation to be added to the stationlist. Default = 3.
+                         observation to be added to the stationlist.
+                         Default = 3.
     Returns:
         StationList: Object containing merged data.
 
@@ -38,16 +44,16 @@ def replace_dyfi(stationfile, dyfi_xml, min_nresp=3):
     cursor = stations.cursor
     query1 = (
         "SELECT id from station WHERE instrumented = "
-        '0 and (network = "DYFI" or network="CIIM")'
+        "0 and (network = 'DYFI' or network='CIIM')"
     )
     cursor.execute(query1)
     rows = cursor.fetchall()
     for row in rows:
         sid = row[0]
-        query2 = f'DELETE FROM amp WHERE station_id="{sid}"'
+        query2 = f"DELETE FROM amp WHERE station_id='{sid}'"
         cursor.execute(query2)
         conn.commit()
-        query3 = f'DELETE FROM station where id="{sid}"'
+        query3 = f"DELETE FROM station where id='{sid}'"
         cursor.execute(query3)
         conn.commit()
 
@@ -106,7 +112,7 @@ def get_extent(config, ipe, rupture=None):
     # -------------------------------------------------------------------------
     # Simplest option: extent was specified in the config, use that and exit.
     # -------------------------------------------------------------------------
-    if len(bounds):
+    if len(bounds) > 0:
         xmin, ymin, xmax, ymax = bounds
         return (
             thirty_sec_min(xmin),
@@ -164,7 +170,7 @@ def get_extent(config, ipe, rupture=None):
     )
 
 
-def _get_extent_from_spans(rupture, spans=[]):
+def _get_extent_from_spans(rupture, spans={}):
     """
     Choose extent based on magnitude using a hardcoded list of spans
     based on magnitude ranges.
@@ -175,8 +181,8 @@ def _get_extent_from_spans(rupture, spans=[]):
     xmax = None
     ymin = None
     ymax = None
-    for spankey, span in spans.items():
-        if mag > span[0] and mag <= span[1]:
+    for span in spans.values():
+        if span[0] < mag <= span[1]:
             ymin = clat - span[2] / 2
             ymax = clat + span[2] / 2
             xmin = clon - span[3] / 2
@@ -258,7 +264,8 @@ def _get_extent_from_multigmpe(rupture, config, ipe):
     proj = OrthographicProjection(clon - 4, clon + 4, clat + 4, clat - 4)
     if isinstance(rupture, (QuadRupture, EdgeRupture)):
         ruptx, rupty = proj(
-            rupture.lons[~np.isnan(rupture.lons)], rupture.lats[~np.isnan(rupture.lats)]
+            rupture.lons[~np.isnan(rupture.lons)],
+            rupture.lats[~np.isnan(rupture.lats)],
         )
     else:
         ruptx, rupty = proj(clon, clat)
@@ -293,7 +300,9 @@ def _get_extent_from_multigmpe(rupture, config, ipe):
     # output grid register with common grid resolutions (60c, 30c,
     # 15c, 7.5c)
     #
-    logging.debug(f"Extent: {lonmin[0]:f}, {lonmax[0]:f}, {latmin[0]:f}, {latmax[0]:f}")
+    logging.debug(
+        "Extent: %f, %f, %f, %f", lonmin[0], lonmax[0], latmin[0], latmax[0]
+    )
     return (
         _round_coord(lonmin[0]),
         _round_coord(lonmax[0]),
@@ -400,7 +409,9 @@ def get_gmpe_coef_table(gmpe):
         cobj = getattr(gmpe, coef_sel)
         if "sa_coeffs" in dir(cobj):
             return cobj
-    raise NotImplementedError(f"GMPE {gmpe} does not contain sa_coeffs attribute.")
+    raise NotImplementedError(
+        f"GMPE {gmpe} does not contain sa_coeffs attribute."
+    )
 
 
 def get_gmpe_sa_periods(gmpe):
